@@ -1,4 +1,9 @@
-#' For a k=1 Gegenbauer process, use semi-parametric methods to obtain short memory version of the process, then run a ggtsdisplay().
+#' ggtsdisplay of underlying ARMA process.
+#'
+#' For a Gegenbauer process, use semi-parametric methods to obtain short memory version of the process, then run a ggtsdisplay().
+#'
+#' The purpose of this function is to ease the process of identifying the underlying short memory process.
+#'
 #' @param x (num) This should be a numeric vector representing the process to estimate.
 #' @param k (int) The number of Gegenbauer factors
 #' @param ... additional parameters to pass to ggtsdisplay
@@ -11,5 +16,5 @@
 garma_ggtsdisplay<-function(x,k=1,...) {
   sp <- ggbr_semipara(x,k=k)
   arma_process <- extract_arma(x, sp$ggbr_factors)
-  ggtsdisplay(arma_process,theme=theme_bw(),...)
+  ggtsdisplay(arma_process,...)
 }
